==> jc-1.4.0.tar.gz: java/awt/CheckboxGroup.h <==
// public class java.awt.CheckboxGroup

// class file dependencies
// @dep_class 51b1b49fb8b0a58b java_awt_CheckboxGroup
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_CheckboxGroup_H_
#define _JC_java_awt_CheckboxGroup_H_

// Forward structure declarations
struct _jc_java_awt_Checkbox$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_CheckboxGroup$sub_refs	_jc_java_awt_CheckboxGroup$sub_refs;
typedef struct _jc_java_awt_CheckboxGroup$sub_nonrefs	_jc_java_awt_CheckboxGroup$sub_nonrefs;
typedef struct _jc_java_awt_CheckboxGroup$refs	_jc_java_awt_CheckboxGroup$refs;
typedef struct _jc_java_awt_CheckboxGroup$nonrefs	_jc_java_awt_CheckboxGroup$nonrefs;
typedef struct _jc_java_awt_CheckboxGroup$object	_jc_java_awt_CheckboxGroup$object;

typedef struct _jc_java_awt_CheckboxGroup$fields_struct	_jc_java_awt_CheckboxGroup$fields_struct;
typedef const struct _jc_java_awt_CheckboxGroup$vmethods	_jc_java_awt_CheckboxGroup$vmethods;
typedef const struct _jc_java_awt_CheckboxGroup$vtable	_jc_java_awt_CheckboxGroup$vtable;
typedef const struct _jc_java_awt_CheckboxGroup$vtype	_jc_java_awt_CheckboxGroup$vtype;

// Class fields structure
struct _jc_java_awt_CheckboxGroup$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_CheckboxGroup$fields_struct _jc_java_awt_CheckboxGroup$class_fields;

// Constructors
extern void _jc_java_awt_CheckboxGroup$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *);

// Virtual methods
extern struct _jc_java_awt_Checkbox$object *_jc_java_awt_CheckboxGroup$method$getCurrent$4e43915fecc88ae9(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *);
extern struct _jc_java_awt_Checkbox$object *_jc_java_awt_CheckboxGroup$method$getSelectedCheckbox$ddacf082bb87c6e2(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *);
extern void _jc_java_awt_CheckboxGroup$method$setCurrent$01b59c833b6a36ba(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *, struct _jc_java_awt_Checkbox$object *);
extern void _jc_java_awt_CheckboxGroup$method$setSelectedCheckbox$9dce72c42f9f87f7(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *, struct _jc_java_awt_Checkbox$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_CheckboxGroup$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$getCurrent$4e43915fecc88ae9;
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$getSelectedCheckbox$ddacf082bb87c6e2;
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$setCurrent$01b59c833b6a36ba;
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$setSelectedCheckbox$9dce72c42f9f87f7;
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_CheckboxGroup$vmethods {
	struct _jc_java_awt_Checkbox$object	*(*getCurrent$4e43915fecc88ae9)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *);
	struct _jc_java_awt_Checkbox$object	*(*getSelectedCheckbox$ddacf082bb87c6e2)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *);
	void	(*setCurrent$01b59c833b6a36ba)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *, struct _jc_java_awt_Checkbox$object *);
	void	(*setSelectedCheckbox$9dce72c42f9f87f7)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *, struct _jc_java_awt_Checkbox$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *);
};

// Vtable
struct _jc_java_awt_CheckboxGroup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_CheckboxGroup$vmethods	java_awt_CheckboxGroup;
};

// Vtype
struct _jc_java_awt_CheckboxGroup$vtype {
	_jc_type			type;
	_jc_java_awt_CheckboxGroup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_CheckboxGroup$sub_refs {
	struct _jc_java_awt_Checkbox$object	*selectedCheckbox;
};

// Reference instance fields (object)
struct _jc_java_awt_CheckboxGroup$refs {
    _jc_java_awt_CheckboxGroup$sub_refs	java_awt_CheckboxGroup;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_CheckboxGroup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_CheckboxGroup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_CheckboxGroup$sub_nonrefs	java_awt_CheckboxGroup;
};

// Object instance structure
struct _jc_java_awt_CheckboxGroup$object {
	_jc_java_awt_CheckboxGroup$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_CheckboxGroup$vtype	*vtype;
	_jc_java_awt_CheckboxGroup$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_CheckboxGroup$vtype _jc_java_awt_CheckboxGroup$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_CheckboxGroup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_CheckboxGroup$class_object;

#endif	/* _JC_java_awt_CheckboxGroup_H_ */

==> jc-1.4.6.tar.gz: java/awt/CheckboxGroup.h <==
// public class java.awt.CheckboxGroup

// class file dependencies
// @dep_class 51b1b49fb8b0a58b java_awt_CheckboxGroup
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_CheckboxGroup_H_
#define _JC_java_awt_CheckboxGroup_H_

// Forward structure declarations
struct _jc_java_awt_Checkbox$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_CheckboxGroup$sub_refs	_jc_java_awt_CheckboxGroup$sub_refs;
typedef struct _jc_java_awt_CheckboxGroup$sub_nonrefs	_jc_java_awt_CheckboxGroup$sub_nonrefs;
typedef struct _jc_java_awt_CheckboxGroup$refs	_jc_java_awt_CheckboxGroup$refs;
typedef struct _jc_java_awt_CheckboxGroup$nonrefs	_jc_java_awt_CheckboxGroup$nonrefs;
typedef struct _jc_java_awt_CheckboxGroup$object	_jc_java_awt_CheckboxGroup$object;

typedef struct _jc_java_awt_CheckboxGroup$fields_struct	_jc_java_awt_CheckboxGroup$fields_struct;
typedef const struct _jc_java_awt_CheckboxGroup$vmethods	_jc_java_awt_CheckboxGroup$vmethods;
typedef const struct _jc_java_awt_CheckboxGroup$vtable	_jc_java_awt_CheckboxGroup$vtable;
typedef const struct _jc_java_awt_CheckboxGroup$vtype	_jc_java_awt_CheckboxGroup$vtype;

// Class fields structure
struct _jc_java_awt_CheckboxGroup$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_CheckboxGroup$fields_struct _jc_java_awt_CheckboxGroup$class_fields;

// Constructors
extern void _jc_java_awt_CheckboxGroup$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Checkbox$object *_jc_java_awt_CheckboxGroup$method$getCurrent$4e43915fecc88ae9(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Checkbox$object *_jc_java_awt_CheckboxGroup$method$getSelectedCheckbox$ddacf082bb87c6e2(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_CheckboxGroup$method$setCurrent$01b59c833b6a36ba(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *, struct _jc_java_awt_Checkbox$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_CheckboxGroup$method$setSelectedCheckbox$9dce72c42f9f87f7(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *, struct _jc_java_awt_Checkbox$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_CheckboxGroup$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$getCurrent$4e43915fecc88ae9;
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$getSelectedCheckbox$ddacf082bb87c6e2;
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$setCurrent$01b59c833b6a36ba;
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$setSelectedCheckbox$9dce72c42f9f87f7;
extern _jc_method _jc_java_awt_CheckboxGroup$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_CheckboxGroup$vmethods {
	struct _jc_java_awt_Checkbox$object	*(*getCurrent$4e43915fecc88ae9)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Checkbox$object	*(*getSelectedCheckbox$ddacf082bb87c6e2)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *) _JC_JCNI_ATTR;
	void	(*setCurrent$01b59c833b6a36ba)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *, struct _jc_java_awt_Checkbox$object *) _JC_JCNI_ATTR;
	void	(*setSelectedCheckbox$9dce72c42f9f87f7)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *, struct _jc_java_awt_Checkbox$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_CheckboxGroup$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_CheckboxGroup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_CheckboxGroup$vmethods	java_awt_CheckboxGroup;
};

// Vtype
struct _jc_java_awt_CheckboxGroup$vtype {
	_jc_type			type;
	_jc_java_awt_CheckboxGroup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_CheckboxGroup$sub_refs {
	struct _jc_java_awt_Checkbox$object	*selectedCheckbox;
};

// Reference instance fields (object)
struct _jc_java_awt_CheckboxGroup$refs {
    _jc_java_awt_CheckboxGroup$sub_refs	java_awt_CheckboxGroup;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_CheckboxGroup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_CheckboxGroup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_CheckboxGroup$sub_nonrefs	java_awt_CheckboxGroup;
};

// Object instance structure
struct _jc_java_awt_CheckboxGroup$object {
	_jc_java_awt_CheckboxGroup$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_CheckboxGroup$vtype	*vtype;
	_jc_java_awt_CheckboxGroup$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_CheckboxGroup$vtype _jc_java_awt_CheckboxGroup$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_CheckboxGroup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_CheckboxGroup$class_object;

#endif	/* _JC_java_awt_CheckboxGroup_H_ */
